@@ -62,7 +62,7 @@
 #define BALOO_WIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BALOO_WIDGETS_NO_DEPRECATED
-#  define BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x180803
+#  define BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x180c02
 #endif
 #ifdef BALOO_WIDGETS_NO_DEPRECATED_WARNINGS
 #  define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0x180803
+#    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0x180c02
 #  endif
 #endif
 
